import { Checker, CheckResult } from '@stryker-mutator/api/check';
import { PluginContext, Injector } from '@stryker-mutator/api/plugin';
import { Logger } from '@stryker-mutator/api/logging';
import { Mutant, StrykerOptions } from '@stryker-mutator/api/core';
import { HybridFileSystem } from './fs/index.js';
export declare function create(injector: Injector<PluginContext>): TypescriptChecker;
export declare namespace create {
    var inject: ["$injector"];
}
/**
 * An in-memory type checker implementation which validates type errors of mutants.
 */
export declare class TypescriptChecker implements Checker {
    private readonly logger;
    private readonly fs;
    private currentTask;
    private readonly currentErrors;
    /**
     * Keep track of all tsconfig files which are read during compilation (for project references)
     */
    private readonly allTSConfigFiles;
    static inject: ["logger", "options", "fs"];
    private readonly tsconfigFile;
    constructor(logger: Logger, options: StrykerOptions, fs: HybridFileSystem);
    /**
     * Starts the typescript compiler and does a dry run
     */
    init(): Promise<void>;
    private guardTSConfigFileExists;
    /**
     * Checks whether or not a mutant results in a compile error.
     * Will simply pass through if the file mutated isn't part of the typescript project
     * @param mutant The mutant to check
     */
    check(mutants: Mutant[]): Promise<Record<string, CheckResult>>;
    /**
     * Post processes the content of a tsconfig file. Adjusts some options for speed and alters quality options.
     * @param fileName The tsconfig file name
     * @param content The tsconfig content
     * @param buildModeEnabled Whether or not `--build` mode is used
     */
    private adjustTSConfigFile;
    /**
     * Resolves the task that is currently running. Will report back the check result.
     */
    private resolveCheckResult;
    /**
     * Clear state between checks
     */
    private clearCheckState;
    private readonly logDiagnostic;
}
//# sourceMappingURL=typescript-checker.d.ts.map